Package: archive
Title: Multi-Format Archive and Compression Support
Version: 1.1.14
Authors@R: c(
    person("Jim", "Hester", role = "aut",
           comment = c(ORCID = "0000-0002-2739-7082")),
    person("Gábor", "Csárdi", , "csardi.gabor@gmail.com", role = c("aut", "cre")),
    person("Ondrej", "Holy", role = "cph",
           comment = "archive_write_add_filter implementation"),
    person("RStudio", role = c("cph", "fnd"))
  )
Description: Bindings to 'libarchive' <http://www.libarchive.org> the
    Multi-format archive and compression library. Offers R connections and
    direct extraction for many archive formats including 'tar', 'ZIP',
    '7-zip', 'RAR', 'CAB' and compression formats including 'gzip',
    'bzip2', 'compress', 'lzma' and 'xz'.
License: MIT + file LICENSE
URL: https://archive.r-lib.org/, https://github.com/r-lib/archive
BugReports: https://github.com/r-lib/archive/issues
Depends: R (>= 4.0.0)
Imports: cli, glue, rlang, tibble
Suggests: testthat
LinkingTo: cli
ByteCompile: true
Encoding: UTF-8
RoxygenNote: 7.2.1.9000
SystemRequirements: libarchive: libarchive-dev (deb), libarchive-devel
        (rpm), libarchive (homebrew), libarchive_dev (csw)
Config/Needs/website: tidyverse/tidytemplate
Biarch: true
NeedsCompilation: yes
Packaged: 2026-07-29 20:43:43 UTC; gaborcsardi
Author: Jim Hester [aut] (ORCID: <https://orcid.org/0000-0002-2739-7082>),
  Gábor Csárdi [aut, cre],
  Ondrej Holy [cph] (archive_write_add_filter implementation),
  RStudio [cph, fnd]
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-30 10:40:09 UTC
Built: R 4.6.1; aarch64-apple-darwin23; 2026-07-30 13:27:02 UTC; unix
Archs: archive.so.dSYM
