			Archive
			A simple archiver
			by Thomas Leonard

Brief
~~~~~
You can use this program to compress a directory or file into a
single, smaller file (which can be stored, emailed, etc).

You can also use it to extract a compressed archive back into a
file or directory structure.

It's written in python, so you don't need to compile it, but you do
need ROX-Lib2 and the pygtk2 package
(http://rox.sourceforge.net/rox_lib.php3).

ROX-Filer will come in handy, too.

To compress:

- Drag the file or directory onto the Archive icon in a ROX-Filer window.
- Type in a name for the archive.
- Drag the icon back into a filer window to create the archive.

To extract an archive:

- Drag the compressed file to Archive.
- Enter a name for the file or directory to create.
- Drag the directory icon into a filer window to extract.

You can use ROX-Filer's `Set Run Action...' menu entry to make clicking
on a compressed file automatically run Archive on it.

The latest version of Archive (and ROX-Filer) is at:

	http://rox.sourceforge.net

The savebox contains a menu of possible actions on the file. Normally, the
default is what you want. When extracting from a file, you have the option to
delete the source file afterwards.


Conditions
~~~~~~~~~~
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

Please report any bugs to the mailing list:

	http://rox.sourceforge.net/phpwiki/index.php/MailingLists
