# Generated by cpp11: do not edit by hand

archive_extract_ <- function(connection, file, num_strip_components, options, password, sz) {
  .Call(`_archive_archive_extract_`, connection, file, num_strip_components, options, password, sz)
}

archive_read_ <- function(connection, file, description, mode, format, filters, options, password, sz) {
  .Call(`_archive_archive_read_`, connection, file, description, mode, format, filters, options, password, sz)
}

archive_write_direct_ <- function(archive_filename, filename, mode, format, filters, options, password, sz) {
  .Call(`_archive_archive_write_direct_`, archive_filename, filename, mode, format, filters, options, password, sz)
}

archive_write_files_ <- function(archive_filename, files, format, filters, options, password, sz) {
  .Call(`_archive_archive_write_files_`, archive_filename, files, format, filters, options, password, sz)
}

archive_write_ <- function(archive_filename, filename, mode, format, filters, options, password, sz) {
  .Call(`_archive_archive_write_`, archive_filename, filename, mode, format, filters, options, password, sz)
}

archive_ <- function(connection, options, password) {
  .Call(`_archive_archive_`, connection, options, password)
}

archive_filters <- function() {
  .Call(`_archive_archive_filters`)
}

archive_formats <- function() {
  .Call(`_archive_archive_formats`)
}

libarchive_version_ <- function() {
  .Call(`_archive_libarchive_version_`)
}

libarchive_zlib_version_ <- function() {
  .Call(`_archive_libarchive_zlib_version_`)
}

libarchive_liblzma_version_ <- function() {
  .Call(`_archive_libarchive_liblzma_version_`)
}

libarchive_bzlib_version_ <- function() {
  .Call(`_archive_libarchive_bzlib_version_`)
}

libarchive_liblz4_version_ <- function() {
  .Call(`_archive_libarchive_liblz4_version_`)
}

libarchive_libzstd_version <- function() {
  .Call(`_archive_libarchive_libzstd_version`)
}

rchive_init <- function(nc_xptr, rc_xptr) {
  invisible(.Call(`_archive_rchive_init`, nc_xptr, rc_xptr))
}
